==> nvtabular-0.11.0.tar.gz: nvtabular-0.11.0/nvtabular/ops/__init__.py <==
#
# Copyright (c) 2021, NVIDIA CORPORATION.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# alias submodules here to avoid breaking everything with moving to submodules
# flake8: noqa
from .add_metadata import AddMetadata
from .bucketize import Bucketize
from .categorify import Categorify, get_embedding_sizes
from .clip import Clip
from .column_similarity import ColumnSimilarity
from .data_stats import DataStats
from .difference_lag import DifferenceLag
from .drop_low_cardinality import DropLowCardinality
from .dropna import Dropna
from .fill import FillMedian, FillMissing
from .filter import Filter
from .groupby import Groupby
from .hash_bucket import HashBucket
from .hashed_cross import HashedCross
from .join_external import JoinExternal
from .join_groupby import JoinGroupby
from .lambdaop import LambdaOp
from .list_slice import ListSlice
from .logop import LogOp
from .normalize import Normalize, NormalizeMinMax
from .operator import ColumnSelector, Operator
from .reduce_dtype_size import ReduceDtypeSize
from .rename import Rename
from .stat_operator import StatOperator
from .target_encoding import TargetEncoding
from .value_counts import ValueCount

==> nvtabular-1.1.0.tar.gz: nvtabular-1.1.0/nvtabular/ops/__init__.py <==
#
# Copyright (c) 2021, NVIDIA CORPORATION.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# alias submodules here to avoid breaking everything with moving to submodules
# flake8: noqa
from .add_metadata import (
    AddMetadata,
    AddProperties,
    AddTags,
    TagAsItemFeatures,
    TagAsItemID,
    TagAsUserFeatures,
    TagAsUserID,
)
from .bucketize import Bucketize
from .categorify import Categorify, get_embedding_sizes
from .clip import Clip
from .column_similarity import ColumnSimilarity
from .data_stats import DataStats
from .difference_lag import DifferenceLag
from .drop_low_cardinality import DropLowCardinality
from .dropna import Dropna
from .fill import FillMedian, FillMissing
from .filter import Filter
from .groupby import Groupby
from .hash_bucket import HashBucket
from .hashed_cross import HashedCross
from .join_external import JoinExternal
from .join_groupby import JoinGroupby
from .lambdaop import LambdaOp
from .list_slice import ListSlice
from .logop import LogOp
from .normalize import Normalize, NormalizeMinMax
from .operator import ColumnSelector, Operator
from .reduce_dtype_size import ReduceDtypeSize
from .rename import Rename
from .stat_operator import StatOperator
from .target_encoding import TargetEncoding
from .value_counts import ValueCount
